@@ -21,7 +21,7 @@
 
 #include "keduvoctext.h"
 
-#include <QtCore/QList>
+#include <QList>
 #include <QUrl>
 
 class KEduVocDocument;
@@ -47,7 +47,7 @@ public:
 
     /** default constructor */
     explicit KEduVocContainer(const QString& name, EnumContainerType type,
-			      KEduVocContainer *parent = 0);
+                  KEduVocContainer *parent = nullptr);
 
     void appendChildContainer(KEduVocContainer *child);
     void insertChildContainer(int row, KEduVocContainer *child);
@@ -112,7 +112,7 @@ public:
     void setInPractice( bool inPractice );
 
     /** equality operator */
-    bool operator==(const KEduVocContainer &other);
+    bool operator==(const KEduVocContainer &other) const;
 
     /**
      * The type of this container. @see EnumContainerType
